@@ -33,6 +33,7 @@ import pyatspi
 
 from . import braille
 from . import debug
+from . import messages
 from . import settings
 
 from .orca_i18n import _         # for gettext support
@@ -828,6 +829,16 @@ class Generator:
         self._restoreRole(oldRole, args)
         return result
 
+    def _generateTable(self, obj, **args):
+        """Returns an array of strings for use by speech and braille to present
+        the size of a table."""
+
+        try:
+            table = obj.queryTable()
+        except:
+            return []
+        return [messages.tableSize(table.nRows, table.nColumns)]       
+
     def _generateTableCellRow(self, obj, **args):
         """Orca has a feature to automatically read an entire row of a table
         as the user arrows up/down the roles.  This leads to complexity in
